@@ -170,15 +170,80 @@ TEST_F(SphericalCoordinatesTest, CoordinateTransforms)
       // elevation
       EXPECT_NEAR(sph.Z(), elev, 1e-6);
 
-      // 200 km offset in x (pi/2 heading offset means North)
+      // 200 km offset in x (pi/2 heading offset means North). We use
+      // SphericalFromLocal, which means that xyz is a linear movement on
+      // a plane (not along the curvature of Earth). This will result in
+      // a large height offset.
       xyz.Set(2e5, 0, 0);
       sph = sc.SphericalFromLocal(xyz);
       // increase in latitude about 1.8 degrees
       EXPECT_NEAR(sph.X(), lat.Degree() + 1.8, 0.008);
       // no change in longitude
-      EXPECT_NEAR(sph.Y(), lon.Degree(), 1e-6);
-      // no change in elevation
-      EXPECT_NEAR(sph.Z(), elev, 1e-6);
+      EXPECT_NEAR(sph.Z(), 3507.024791, 1e-6);
+
+      ignition::math::Vector3d xyz2 = sc.LocalFromSpherical(sph);
+      EXPECT_EQ(xyz, xyz2);
+    }
+
+    // Check position projection
+    {
+      // WGS84 coordinate obtained from online mapping software
+      // > gdaltransform -s_srs WGS84 -t_srs EPSG:4978
+      // > latitude longitude altitude
+      // > X Y Z
+      ignition::math::Vector3d tmp;
+      ignition::math::Vector3d osrf_s(37.3877349, -122.0651166, 32.0);
+      ignition::math::Vector3d osrf_e(
+          -2693701.91434394, -4299942.14687992, 3851691.0393571);
+      ignition::math::Vector3d goog_s(37.4216719, -122.0821853, 30.0);
+      ignition::math::Vector3d goog_e(
+          -2693766.71906146, -4297199.59926038, 3854681.81878812);
+
+      // Local tangent plane coordinates (ENU = GLOBAL) coordinates of
+      // Google when OSRF is taken as the origin:
+      // > proj +ellps=WGS84  +proj=tmerc
+      // +lat_0=37.3877349 +lon_0=-122.0651166 +k=1 +x_0=0 +y_0=0
+      // > -122.0821853 37.4216719 (LON,LAT)
+      // > -1510.88 3766.64 (EAST,NORTH)
+      ignition::math::Vector3d vec(-1510.88, 3766.64, -3.29);
+
+      // Convert degrees to radians
+      osrf_s.X() *= 0.0174532925;
+      osrf_s.Y() *= 0.0174532925;
+
+      // Set the ORIGIN to be the Open Source Robotics Foundation
+      common::SphericalCoordinates sc2(st, ignition::math::Angle(osrf_s.X()),
+          ignition::math::Angle(osrf_s.Y()), osrf_s.Z(), 0.0);
+
+      // Check that SPHERICAL -> ECEF works
+      tmp = sc2.PositionTransform(osrf_s,
+          common::SphericalCoordinates::SPHERICAL,
+          common::SphericalCoordinates::ECEF);
+
+      EXPECT_NEAR(tmp.X(), osrf_e.X(), 8e-2);
+      EXPECT_NEAR(tmp.Y(), osrf_e.Y(), 8e-2);
+      EXPECT_NEAR(tmp.Z(), osrf_e.Z(), 1e-2);
+
+      // Check that ECEF -> SPHERICAL works
+      tmp = sc2.PositionTransform(tmp,
+          common::SphericalCoordinates::ECEF,
+          common::SphericalCoordinates::SPHERICAL);
+
+      EXPECT_NEAR(tmp.X(), osrf_s.X(), 1e-2);
+      EXPECT_NEAR(tmp.Y(), osrf_s.Y(), 1e-2);
+      EXPECT_NEAR(tmp.Z(), osrf_s.Z(), 1e-2);
+
+      // Check that SPHERICAL -> LOCAL works
+      tmp = sc2.LocalFromSpherical(goog_s);
+      EXPECT_NEAR(tmp.X(), vec.X(), 8e-2);
+      EXPECT_NEAR(tmp.Y(), vec.Y(), 8e-2);
+      EXPECT_NEAR(tmp.Z(), vec.Z(), 1e-2);
+
+      // Check that SPHERICAL -> LOCAL -> SPHERICAL works
+      tmp = sc2.SphericalFromLocal(tmp);
+      EXPECT_NEAR(tmp.X(), goog_s.X(), 8e-2);
+      EXPECT_NEAR(tmp.Y(), goog_s.Y(), 8e-2);
+      EXPECT_NEAR(tmp.Z(), goog_s.Z(), 1e-2);
     }
   }
 }
