@@ -20,6 +20,8 @@
   #include <Winsock2.h>
 #endif
 
+#include <boost/algorithm/string.hpp>
+#include <boost/bind.hpp>
 #include <iomanip>
 
 #include "gazebo/rendering/UserCamera.hh"
