@@ -23,6 +23,8 @@
 
 #include <sstream>
 #include <set>
+#include <boost/bind.hpp>
+#include <boost/filesystem.hpp>
 
 #include "gazebo/common/Exception.hh"
 
