@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2014 Open Source Robotics Foundation
+ * Copyright (C) 2012-2015 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,6 +14,14 @@
  * limitations under the License.
  *
 */
+
+
+#ifdef _WIN32
+  // Ensure that Winsock2.h is included before Windows.h, which can get
+  // pulled in by anybody (e.g., Boost).
+  #include <Winsock2.h>
+#endif
+
 #include <boost/thread/recursive_mutex.hpp>
 #include <sstream>
 #include <limits>
@@ -109,16 +117,14 @@ void Actor::Load(sdf::ElementPtr _sdf)
 //    this->AddSphereInertia(linkSdf, math::Pose(), 1.0, 0.01);
 //    this->AddSphereCollision(linkSdf, actorName + "_pose_col",
 //                                             math::Pose(), 0.02);
-    this->AddBoxVisual(linkSdf, actorName + "_pose_vis", math::Pose(),
-                       math::Vector3(0.05, 0.05, 0.05), "Gazebo/White",
-                       Color::White);
+    // this->AddBoxVisual(linkSdf, actorName + "_pose_vis", math::Pose(),
+    //                   math::Vector3(0.05, 0.05, 0.05), "Gazebo/White",
+    //                   Color::White);
     this->AddActorVisual(linkSdf, actorName + "_visual", math::Pose());
-
-    this->visualName = actorName + "::" + actorName + "_pose::"
+    std::string actorLinkName = actorName + "::" + actorName + "_pose";
+    this->visualName = actorLinkName + "::"
                              + actorName + "_visual";
 
-    this->visualId = gazebo::physics::getUniqueId();
-
     for (NodeMapIter iter = nodes.begin(); iter != nodes.end(); ++iter)
     {
       SkeletonNode* bone = iter->second;
@@ -128,10 +134,10 @@ void Actor::Load(sdf::ElementPtr _sdf)
       linkSdf->GetAttribute("name")->Set(bone->GetName());
       linkSdf->GetElement("gravity")->Set(false);
       linkPose = linkSdf->GetElement("pose");
-      math::Pose pose(bone->GetModelTransform().GetTranslation(),
-                      bone->GetModelTransform().GetRotation());
+      ignition::math::Pose3d pose(bone->ModelTransform().Translation(),
+                                  bone->ModelTransform().Rotation());
       if (bone->IsRootNode())
-        pose = math::Pose();
+        pose = ignition::math::Pose3d();
       linkPose->Set(pose);
 
       /// FIXME hardcoded inertia of a sphere with mass 1.0 and radius 0.01
@@ -163,20 +169,22 @@ void Actor::Load(sdf::ElementPtr _sdf)
       {
         SkeletonNode *curChild = bone->GetChild(i);
 
-        math::Vector3 dir = curChild->GetModelTransform().GetTranslation() -
-            bone->GetModelTransform().GetTranslation();
+        math::Vector3 dir = curChild->ModelTransform().Translation() -
+            bone->ModelTransform().Translation();
         double length = dir.GetLength();
 
         if (!math::equal(length, 0.0))
         {
-          math::Vector3 r = curChild->GetTransform().GetTranslation();
-          math::Vector3 linkPos = math::Vector3(r.x / 2.0,
-                                    r.y / 2.0, r.z / 2.0);
+          ignition::math::Vector3d r =
+            curChild->Transform().Translation();
+          ignition::math::Vector3d linkPos =
+            ignition::math::Vector3d(r.X() / 2.0, r.Y() / 2.0, r.Z() / 2.0);
           double theta = atan2(dir.y, dir.x);
           double phi = acos(dir.z / length);
 
-          math::Pose bonePose(linkPos, math::Quaternion(0.0, phi, theta));
-          bonePose.rot = pose.rot.GetInverse() * bonePose.rot;
+          ignition::math::Pose3d bonePose(linkPos,
+              ignition::math::Quaterniond(0.0, phi, theta));
+          bonePose.Rot() = pose.Rot().Inverse() * bonePose.Rot();
 
           this->AddBoxVisual(linkSdf, bone->GetName() + "_" +
             curChild->GetName() + "__SKELETON_VISUAL__", bonePose,
@@ -197,6 +205,20 @@ void Actor::Load(sdf::ElementPtr _sdf)
 
     /// we are ready to load the links
     Model::Load(_sdf);
+    LinkPtr actorLinkPtr = Model::GetLink(actorLinkName);
+    if (actorLinkPtr)
+    {
+       msgs::Visual actorVisualMsg = actorLinkPtr->GetVisualMessage(
+         this->visualName);
+       if (actorVisualMsg.has_id())
+         this->visualId = actorVisualMsg.id();
+       else
+         gzerr << "No actor visual message found.";
+    }
+    else
+    {
+      gzerr << "No actor link found.";
+    }
     this->bonePosePub = this->node->Advertise<msgs::PoseAnimation>(
                                        "~/skeleton_pose/info", 10);
   }
@@ -264,12 +286,12 @@ void Actor::LoadScript(sdf::ElementPtr _sdf)
           if (pIter == points.begin() && !math::equal(pIter->first, 0.0))
           {
             key = anim->CreateKeyFrame(0.0);
-            key->SetTranslation(pIter->second.pos);
-            key->SetRotation(pIter->second.rot);
+            key->Translation(pIter->second.pos.Ign());
+            key->Rotation(pIter->second.rot.Ign());
           }
           key = anim->CreateKeyFrame(pIter->first);
-          key->SetTranslation(pIter->second.pos);
-          key->SetRotation(pIter->second.rot);
+          key->Translation(pIter->second.pos.Ign());
+          key->Rotation(pIter->second.rot.Ign());
         }
 
         this->trajectories[this->trajInfo[idx].id] = anim;
@@ -428,7 +450,11 @@ void Actor::Update()
   common::Time currentTime = this->world->GetSimTime();
 
   /// do not refresh animation more faster the 30 Hz sim time
-  if ((currentTime - this->prevFrameTime).Double() < (1.0 / 30.0))
+  /// TODO: Reducing to 20 Hz. Because there were memory corruption
+  /// and segmentation faults. Possibly due to some dangling pointers
+  /// in pose message processing. This will need a proper fix. Just a
+  /// workaround for now.
+  if ((currentTime - this->prevFrameTime).Double() < (1.0 / 20.0))
     return;
 
   double scriptTime = currentTime.Double() - this->startDelay -
@@ -467,51 +493,54 @@ void Actor::Update()
   SkeletonAnimation *skelAnim = this->skelAnimation[tinfo.type];
   std::map<std::string, std::string> skelMap = this->skelNodesMap[tinfo.type];
 
-  math::Pose modelPose;
-  std::map<std::string, math::Matrix4> frame;
+  ignition::math::Pose3d modelPose;
+  std::map<std::string, ignition::math::Matrix4d> frame;
   if (this->trajectories.find(tinfo.id) != this->trajectories.end())
   {
     common::PoseKeyFrame posFrame(0.0);
     this->trajectories[tinfo.id]->SetTime(scriptTime);
     this->trajectories[tinfo.id]->GetInterpolatedKeyFrame(posFrame);
-    modelPose.pos = posFrame.GetTranslation();
-    modelPose.rot = posFrame.GetRotation();
+
+    modelPose.Pos() = posFrame.Translation();
+    modelPose.Rot() = posFrame.Rotation();
 
     if (this->lastTraj == tinfo.id)
-      this->pathLength += fabs(this->lastPos.Distance(modelPose.pos));
+      this->pathLength += fabs(this->lastPos.Distance(modelPose.Pos()));
     else
     {
       common::PoseKeyFrame *frame0 = dynamic_cast<common::PoseKeyFrame*>
         (this->trajectories[tinfo.id]->GetKeyFrame(0));
-      this->pathLength = fabs(modelPose.pos.Distance(frame0->GetTranslation()));
+      ignition::math::Vector3d vector3Ign;
+      vector3Ign = frame0->Translation();
+      this->pathLength = fabs(modelPose.Pos().Distance(vector3Ign));
     }
-    this->lastPos = modelPose.pos;
+    this->lastPos = modelPose.Pos();
   }
   if (this->interpolateX[tinfo.type] &&
         this->trajectories.find(tinfo.id) != this->trajectories.end())
   {
-    frame = skelAnim->GetPoseAtX(this->pathLength,
+    frame = skelAnim->PoseAtX(this->pathLength,
               skelMap[this->skeleton->GetRootNode()->GetName()]);
   }
   else
-    frame = skelAnim->GetPoseAt(scriptTime);
+    frame = skelAnim->PoseAt(scriptTime);
 
   this->lastTraj = tinfo.id;
 
-  math::Matrix4 rootTrans =
-                  frame[skelMap[this->skeleton->GetRootNode()->GetName()]];
+  ignition::math::Matrix4d rootTrans =
+    frame[skelMap[this->skeleton->GetRootNode()->GetName()]];
 
-  math::Vector3 rootPos = rootTrans.GetTranslation();
-  math::Quaternion rootRot = rootTrans.GetRotation();
+  ignition::math::Vector3d rootPos = rootTrans.Translation();
+  ignition::math::Quaterniond rootRot = rootTrans.Rotation();
 
   if (tinfo.translated)
-    rootPos.x = 0.0;
-  math::Pose actorPose;
-  actorPose.pos = modelPose.pos + modelPose.rot.RotateVector(rootPos);
-  actorPose.rot = modelPose.rot *rootRot;
+    rootPos.X() = 0.0;
+  ignition::math::Pose3d actorPose;
+  actorPose.Pos() = modelPose.Pos() + modelPose.Rot().RotateVector(rootPos);
+  actorPose.Rot() = modelPose.Rot() * rootRot;
 
-  math::Matrix4 rootM(actorPose.rot.GetAsMatrix4());
-  rootM.SetTranslate(actorPose.pos);
+  ignition::math::Matrix4d rootM(actorPose.Rot());
+  rootM.Translate(actorPose.Pos());
 
   frame[skelMap[this->skeleton->GetRootNode()->GetName()]] = rootM;
 
@@ -520,6 +549,83 @@ void Actor::Update()
   this->lastScriptTime = scriptTime;
 }
 
+//////////////////////////////////////////////////
+void Actor::SetPose(std::map<std::string, ignition::math::Matrix4d> _frame,
+      std::map<std::string, std::string> _skelMap, double _time)
+{
+  msgs::PoseAnimation msg;
+  msg.set_model_name(this->visualName);
+  msg.set_model_id(this->visualId);
+
+  ignition::math::Matrix4d modelTrans(ignition::math::Matrix4d::Identity);
+  ignition::math::Pose3d mainLinkPose;
+
+  for (unsigned int i = 0; i < this->skeleton->GetNumNodes(); i++)
+  {
+    SkeletonNode *bone = this->skeleton->GetNodeByHandle(i);
+    SkeletonNode *parentBone = bone->GetParent();
+    ignition::math::Matrix4d transform(ignition::math::Matrix4d::Identity);
+    if (_frame.find(_skelMap[bone->GetName()]) != _frame.end())
+      transform = _frame[_skelMap[bone->GetName()]];
+    else
+      transform = bone->Transform();
+
+    LinkPtr currentLink = this->GetChildLink(bone->GetName());
+    ignition::math::Pose3d bonePose = transform.Pose();
+
+    if (!bonePose.IsFinite())
+    {
+      std::cerr << "ACTOR: " << _time << " " << bone->GetName()
+                << " " << bonePose << "\n";
+      bonePose.Correct();
+    }
+
+    msgs::Pose *bone_pose = msg.add_pose();
+    bone_pose->set_name(bone->GetName());
+
+    if (!parentBone)
+    {
+      bone_pose->mutable_position()->CopyFrom(
+          msgs::Convert(ignition::math::Vector3d()));
+      bone_pose->mutable_orientation()->CopyFrom(msgs::Convert(
+            ignition::math::Quaterniond()));
+      mainLinkPose = bonePose;
+    }
+    else
+    {
+      bone_pose->mutable_position()->CopyFrom(msgs::Convert(bonePose.Pos()));
+      bone_pose->mutable_orientation()->CopyFrom(msgs::Convert(bonePose.Rot()));
+      LinkPtr parentLink = this->GetChildLink(parentBone->GetName());
+      math::Pose parentPose = parentLink->GetWorldPose();
+      math::Matrix4 parentTrans(parentPose.rot.GetAsMatrix4());
+      parentTrans.SetTranslate(parentPose.pos);
+      transform = (parentTrans * transform).Ign();
+    }
+
+    msgs::Pose *link_pose = msg.add_pose();
+    link_pose->set_name(currentLink->GetScopedName());
+    link_pose->set_id(currentLink->GetId());
+    ignition::math::Pose3d linkPose = transform.Pose() - mainLinkPose;
+    link_pose->mutable_position()->CopyFrom(msgs::Convert(linkPose.Pos()));
+    link_pose->mutable_orientation()->CopyFrom(msgs::Convert(linkPose.Rot()));
+    currentLink->SetWorldPose(transform.Pose(), true, false);
+  }
+
+  msgs::Time *stamp = msg.add_time();
+  stamp->CopyFrom(msgs::Convert(_time));
+
+  msgs::Pose *model_pose = msg.add_pose();
+  model_pose->set_name(this->GetScopedName());
+  model_pose->set_id(this->GetId());
+  model_pose->mutable_position()->CopyFrom(msgs::Convert(mainLinkPose.Pos()));
+  model_pose->mutable_orientation()->CopyFrom(
+      msgs::Convert(mainLinkPose.Rot()));
+
+  if (this->bonePosePub && this->bonePosePub->HasConnections())
+    this->bonePosePub->Publish(msg);
+  this->SetWorldPose(mainLinkPose, true, false);
+}
+
 //////////////////////////////////////////////////
 void Actor::SetPose(std::map<std::string, math::Matrix4> _frame,
       std::map<std::string, std::string> _skelMap, double _time)
@@ -539,7 +645,7 @@ void Actor::SetPose(std::map<std::string, math::Matrix4> _frame,
     if (_frame.find(_skelMap[bone->GetName()]) != _frame.end())
       transform = _frame[_skelMap[bone->GetName()]];
     else
-      transform = bone->GetTransform();
+      transform = bone->Transform();
 
     LinkPtr currentLink = this->GetChildLink(bone->GetName());
     math::Pose bonePose = transform.GetAsPose();
@@ -556,15 +662,18 @@ void Actor::SetPose(std::map<std::string, math::Matrix4> _frame,
 
     if (!parentBone)
     {
-      bone_pose->mutable_position()->CopyFrom(msgs::Convert(math::Vector3()));
+      bone_pose->mutable_position()->CopyFrom(
+          msgs::Convert(ignition::math::Vector3d()));
       bone_pose->mutable_orientation()->CopyFrom(msgs::Convert(
-                                                    math::Quaternion()));
+            ignition::math::Quaterniond()));
       mainLinkPose = bonePose;
     }
     else
     {
-      bone_pose->mutable_position()->CopyFrom(msgs::Convert(bonePose.pos));
-      bone_pose->mutable_orientation()->CopyFrom(msgs::Convert(bonePose.rot));
+      bone_pose->mutable_position()->CopyFrom(
+          msgs::Convert(bonePose.pos.Ign()));
+      bone_pose->mutable_orientation()->CopyFrom(
+          msgs::Convert(bonePose.rot.Ign()));
       LinkPtr parentLink = this->GetChildLink(parentBone->GetName());
       math::Pose parentPose = parentLink->GetWorldPose();
       math::Matrix4 parentTrans(parentPose.rot.GetAsMatrix4());
@@ -574,10 +683,12 @@ void Actor::SetPose(std::map<std::string, math::Matrix4> _frame,
 
     msgs::Pose *link_pose = msg.add_pose();
     link_pose->set_name(currentLink->GetScopedName());
+    link_pose->set_id(currentLink->GetId());
     math::Pose linkPose = transform.GetAsPose() - mainLinkPose;
-    link_pose->mutable_position()->CopyFrom(msgs::Convert(linkPose.pos));
-    link_pose->mutable_orientation()->CopyFrom(msgs::Convert(linkPose.rot));
-
+    link_pose->mutable_position()->CopyFrom(
+        msgs::Convert(linkPose.pos.Ign()));
+    link_pose->mutable_orientation()->CopyFrom(
+        msgs::Convert(linkPose.rot.Ign()));
     currentLink->SetWorldPose(transform.GetAsPose(), true, false);
   }
 
@@ -586,8 +697,11 @@ void Actor::SetPose(std::map<std::string, math::Matrix4> _frame,
 
   msgs::Pose *model_pose = msg.add_pose();
   model_pose->set_name(this->GetScopedName());
-  model_pose->mutable_position()->CopyFrom(msgs::Convert(mainLinkPose.pos));
-  model_pose->mutable_orientation()->CopyFrom(msgs::Convert(mainLinkPose.rot));
+  model_pose->set_id(this->GetId());
+  model_pose->mutable_position()->CopyFrom(
+      msgs::Convert(mainLinkPose.pos.Ign()));
+  model_pose->mutable_orientation()->CopyFrom(
+      msgs::Convert(mainLinkPose.rot.Ign()));
 
   if (this->bonePosePub && this->bonePosePub->HasConnections())
     this->bonePosePub->Publish(msg);
@@ -692,7 +806,7 @@ void Actor::AddActorVisual(sdf::ElementPtr _linkSdf, const std::string &_name,
   visualPoseSdf->Set(_pose);
   sdf::ElementPtr geomVisSdf = visualSdf->GetElement("geometry");
   sdf::ElementPtr meshSdf = geomVisSdf->GetElement("mesh");
-  meshSdf->GetElement("filename")->Set(this->skinFile);
+  meshSdf->GetElement("uri")->Set(this->skinFile);
   meshSdf->GetElement("scale")->Set(math::Vector3(this->skinScale,
       this->skinScale, this->skinScale));
 }
